@@ -127,6 +127,12 @@ func TestConvertFrom(t *testing.T) {
 										Cpu:    resource.MustParse("2"),
 									},
 								},
+								Env: []corev1.EnvVar{
+									{
+										Name:  "database-name",
+										Value: "database-value",
+									},
+								},
 							},
 						},
 						SecurityContext: &chev2.PodSecurityContext{
@@ -159,6 +165,12 @@ func TestConvertFrom(t *testing.T) {
 										Cpu:    resource.MustParse("2"),
 									},
 								},
+								Env: []corev1.EnvVar{
+									{
+										Name:  "plugin-registry-name",
+										Value: "plugin-registry-value",
+									},
+								},
 							},
 						},
 						SecurityContext: &chev2.PodSecurityContext{
@@ -175,6 +187,7 @@ func TestConvertFrom(t *testing.T) {
 							Url: "ExternalPluginRegistries_2",
 						},
 					},
+					OpenVSXURL: "open-vsx-registry",
 				},
 				DevfileRegistry: chev2.DevfileRegistry{
 					Deployment: &chev2.Deployment{
@@ -192,6 +205,12 @@ func TestConvertFrom(t *testing.T) {
 										Cpu:    resource.MustParse("2"),
 									},
 								},
+								Env: []corev1.EnvVar{
+									{
+										Name:  "devfile-registry-name",
+										Value: "devfile-registry-value",
+									},
+								},
 							},
 						},
 						SecurityContext: &chev2.PodSecurityContext{
@@ -222,6 +241,12 @@ func TestConvertFrom(t *testing.T) {
 										Cpu:    resource.MustParse("2"),
 									},
 								},
+								Env: []corev1.EnvVar{
+									{
+										Name:  "dashboard-name",
+										Value: "dashboard-value",
+									},
+								},
 							},
 						},
 						SecurityContext: &chev2.PodSecurityContext{
@@ -254,7 +279,12 @@ func TestConvertFrom(t *testing.T) {
 										Cpu:    resource.MustParse("2"),
 									},
 								},
-							},
+								Env: []corev1.EnvVar{
+									{
+										Name:  "che-server-name",
+										Value: "che-server-value",
+									},
+								}},
 						},
 						SecurityContext: &chev2.PodSecurityContext{
 							RunAsUser: pointer.Int64Ptr(64),
@@ -276,6 +306,12 @@ func TestConvertFrom(t *testing.T) {
 						Containers: []chev2.Container{
 							{
 								Image: "DevWorkspaceImage",
+								Env: []corev1.EnvVar{
+									{
+										Name:  "dev-workspace-name",
+										Value: "dev-workspace-value",
+									},
+								},
 							},
 						},
 					},
@@ -295,18 +331,42 @@ func TestConvertFrom(t *testing.T) {
 								{
 									Name:  "gateway",
 									Image: "GatewayImage",
+									Env: []corev1.EnvVar{
+										{
+											Name:  "gateway-name",
+											Value: "gateway-value",
+										},
+									},
 								},
 								{
 									Name:  "configbump",
 									Image: "ConfigSidecarImage",
+									Env: []corev1.EnvVar{
+										{
+											Name:  "configbump-name",
+											Value: "configbump-value",
+										},
+									},
 								},
 								{
 									Name:  "oauth-proxy",
 									Image: "AuthenticationSidecarImage",
+									Env: []corev1.EnvVar{
+										{
+											Name:  "oauth-proxy-name",
+											Value: "oauth-proxy-value",
+										},
+									},
 								},
 								{
 									Name:  "kube-rbac-proxy",
 									Image: "AuthorizationSidecarImage",
+									Env: []corev1.EnvVar{
+										{
+											Name:  "kube-rbac-proxy-name",
+											Value: "kube-rbac-proxy-value",
+										},
+									},
 								},
 							},
 						},
@@ -322,10 +382,14 @@ func TestConvertFrom(t *testing.T) {
 					GitTrustedCertsConfigMapName: "che-git-self-signed-cert",
 				},
 				Storage: chev2.WorkspaceStorage{
-					Pvc: &chev2.PVC{
+					PerUserStrategyPvcConfig: &chev2.PVC{
 						ClaimSize:    "StorageClaimSize",
 						StorageClass: "StorageClass",
 					},
+					PerWorkspaceStrategyPvcConfig: &chev2.PVC{
+						ClaimSize:    "PerWorkspaceStorageClaimSize",
+						StorageClass: "PerWorkspaceStorageClass",
+					},
 					PvcStrategy: "PvcStrategy",
 				},
 				DefaultPlugins: []chev2.WorkspaceDefaultPlugins{
@@ -347,6 +411,8 @@ func TestConvertFrom(t *testing.T) {
 					Value:    "Value",
 					Effect:   "Effect",
 				}},
+				SecondsOfInactivityBeforeIdling: pointer.Int32Ptr(1800),
+				SecondsOfRunBeforeIdling:        pointer.Int32Ptr(-1),
 			},
 			ContainerRegistry: chev2.CheClusterContainerRegistry{
 				Hostname:     "AirGapContainerRegistryHostname",
@@ -388,6 +454,14 @@ func TestConvertFrom(t *testing.T) {
 	assert.Equal(t, checlusterv1.Spec.Auth.OAuthSecret, "OAuthSecret")
 	assert.Equal(t, checlusterv1.Spec.Auth.OAuthScope, "OAuthScope")
 	assert.Equal(t, checlusterv1.Spec.Auth.IdentityToken, "IdentityToken")
+	assert.Equal(t, checlusterv1.Spec.Auth.GatewayEnv[0].Name, "gateway-name")
+	assert.Equal(t, checlusterv1.Spec.Auth.GatewayEnv[0].Value, "gateway-value")
+	assert.Equal(t, checlusterv1.Spec.Auth.GatewayKubeRbacProxyEnv[0].Name, "kube-rbac-proxy-name")
+	assert.Equal(t, checlusterv1.Spec.Auth.GatewayKubeRbacProxyEnv[0].Value, "kube-rbac-proxy-value")
+	assert.Equal(t, checlusterv1.Spec.Auth.GatewayOAuthProxyEnv[0].Name, "oauth-proxy-name")
+	assert.Equal(t, checlusterv1.Spec.Auth.GatewayOAuthProxyEnv[0].Value, "oauth-proxy-value")
+	assert.Equal(t, checlusterv1.Spec.Auth.GatewayConfigBumpEnv[0].Name, "configbump-name")
+	assert.Equal(t, checlusterv1.Spec.Auth.GatewayConfigBumpEnv[0].Value, "configbump-value")
 
 	assert.Equal(t, checlusterv1.Spec.Database.ChePostgresContainerResources.Limits.Cpu, "2")
 	assert.Equal(t, checlusterv1.Spec.Database.ChePostgresContainerResources.Limits.Memory, "228Mi")
@@ -402,16 +476,30 @@ func TestConvertFrom(t *testing.T) {
 	assert.Equal(t, checlusterv1.Spec.Database.PostgresImagePullPolicy, corev1.PullAlways)
 	assert.Equal(t, checlusterv1.Spec.Database.PostgresVersion, "PostgresVersion")
 	assert.Equal(t, checlusterv1.Spec.Database.PvcClaimSize, "DatabaseClaimSize")
+	assert.Equal(t, checlusterv1.Spec.Database.PostgresEnv[0].Name, "database-name")
+	assert.Equal(t, checlusterv1.Spec.Database.PostgresEnv[0].Value, "database-value")
 
 	assert.Equal(t, checlusterv1.Spec.DevWorkspace.ControllerImage, "DevWorkspaceImage")
 	assert.Equal(t, checlusterv1.Spec.DevWorkspace.RunningLimit, "RunningLimit")
+	assert.Equal(t, checlusterv1.Spec.DevWorkspace.SecondsOfInactivityBeforeIdling, pointer.Int32Ptr(1800))
+	assert.Equal(t, checlusterv1.Spec.DevWorkspace.SecondsOfRunBeforeIdling, pointer.Int32Ptr(-1))
 	assert.True(t, checlusterv1.Spec.DevWorkspace.Enable)
+	assert.Equal(t, checlusterv1.Spec.DevWorkspace.Env[0].Name, "dev-workspace-name")
+	assert.Equal(t, checlusterv1.Spec.DevWorkspace.Env[0].Value, "dev-workspace-value")
 
 	assert.Equal(t, checlusterv1.Spec.Dashboard.Warning, "DashboardWarning")
 
 	assert.Equal(t, checlusterv1.Spec.ImagePuller.Enable, true)
 	assert.Equal(t, checlusterv1.Spec.Metrics.Enable, true)
 
+	assert.Equal(t, checlusterv1.Spec.Server.CheServerEnv[0].Name, "che-server-name")
+	assert.Equal(t, checlusterv1.Spec.Server.CheServerEnv[0].Value, "che-server-value")
+	assert.Equal(t, checlusterv1.Spec.Server.PluginRegistryEnv[0].Name, "plugin-registry-name")
+	assert.Equal(t, checlusterv1.Spec.Server.PluginRegistryEnv[0].Value, "plugin-registry-value")
+	assert.Equal(t, checlusterv1.Spec.Server.DevfileRegistryEnv[0].Name, "devfile-registry-name")
+	assert.Equal(t, checlusterv1.Spec.Server.DevfileRegistryEnv[0].Value, "devfile-registry-value")
+	assert.Equal(t, checlusterv1.Spec.Server.DashboardEnv[0].Name, "dashboard-name")
+	assert.Equal(t, checlusterv1.Spec.Server.DashboardEnv[0].Value, "dashboard-value")
 	assert.Equal(t, checlusterv1.Spec.Server.AirGapContainerRegistryHostname, "AirGapContainerRegistryHostname")
 	assert.Equal(t, checlusterv1.Spec.Server.AirGapContainerRegistryOrganization, "AirGapContainerRegistryOrganization")
 	assert.Equal(t, checlusterv1.Spec.Server.CheClusterRoles, "ClusterRoles_1,ClusterRoles_2")
@@ -438,6 +526,7 @@ func TestConvertFrom(t *testing.T) {
 	assert.Equal(t, checlusterv1.Spec.Server.ExternalPluginRegistry, true)
 	assert.Equal(t, checlusterv1.Spec.Server.GitSelfSignedCert, true)
 	assert.Equal(t, checlusterv1.Spec.Server.NonProxyHosts, "NonProxyHosts_1|NonProxyHosts_2")
+	assert.Equal(t, checlusterv1.Spec.Server.OpenVSXRegistryURL, "open-vsx-registry")
 	assert.Equal(t, checlusterv1.Spec.Server.PluginRegistryCpuLimit, "2")
 	assert.Equal(t, checlusterv1.Spec.Server.PluginRegistryCpuRequest, "1")
 	assert.Equal(t, checlusterv1.Spec.Server.PluginRegistryImage, "PluginRegistryImage")
@@ -469,8 +558,50 @@ func TestConvertFrom(t *testing.T) {
 	})
 	assert.Equal(t, checlusterv1.Spec.Server.WorkspacesDefaultPlugins, []chev1.WorkspacesDefaultPlugins{{Editor: "Editor", Plugins: []string{"Plugins_1", "Plugins_2"}}})
 
+	assert.Equal(t, checlusterv1.Spec.Storage.PvcStrategy, "PvcStrategy")
 	assert.Equal(t, checlusterv1.Spec.Storage.PostgresPVCStorageClassName, "DatabaseStorageClass")
 	assert.Equal(t, checlusterv1.Spec.Storage.PvcClaimSize, "StorageClaimSize")
-	assert.Equal(t, checlusterv1.Spec.Storage.PvcStrategy, "PvcStrategy")
 	assert.Equal(t, checlusterv1.Spec.Storage.WorkspacePVCStorageClassName, "StorageClass")
+	assert.Equal(t, checlusterv1.Spec.Storage.PerWorkspaceStrategyPvcClaimSize, "PerWorkspaceStorageClaimSize")
+	assert.Equal(t, checlusterv1.Spec.Storage.PerWorkspaceStrategyPVCStorageClassName, "PerWorkspaceStorageClass")
+}
+
+func TestShouldConvertFromWhenOnlyMemoryResourceSpecified(t *testing.T) {
+	infrastructure.InitializeForTesting(infrastructure.OpenShiftv4)
+
+	checlusterv2 := &chev2.CheCluster{
+		ObjectMeta: metav1.ObjectMeta{
+			Name:      "eclipse-che",
+			Namespace: "eclipse-che",
+		},
+		Spec: chev2.CheClusterSpec{
+			Components: chev2.CheClusterComponents{
+				CheServer: chev2.CheServer{
+					Deployment: &chev2.Deployment{
+						Containers: []chev2.Container{
+							{
+								Resources: &chev2.ResourceRequirements{
+									Requests: &chev2.ResourceList{
+										Memory: resource.MustParse("128Mi"),
+									},
+									Limits: &chev2.ResourceList{
+										Memory: resource.MustParse("228Mi"),
+									},
+								},
+							},
+						},
+					},
+				},
+			},
+		},
+	}
+
+	checlusterv1 := &chev1.CheCluster{}
+	err := checlusterv1.ConvertFrom(checlusterv2)
+	assert.Nil(t, err)
+
+	assert.Empty(t, checlusterv1.Spec.Server.ServerCpuLimit)
+	assert.Empty(t, checlusterv1.Spec.Server.ServerCpuRequest)
+	assert.Equal(t, checlusterv1.Spec.Server.ServerMemoryLimit, "228Mi")
+	assert.Equal(t, checlusterv1.Spec.Server.ServerMemoryRequest, "128Mi")
 }
