@@ -17,6 +17,8 @@ import (
 	"strconv"
 	"strings"
 
+	"k8s.io/apimachinery/pkg/api/resource"
+
 	"github.com/eclipse-che/che-operator/pkg/common/utils"
 
 	"github.com/devfile/devworkspace-operator/pkg/infrastructure"
@@ -109,6 +111,7 @@ func (dst *CheCluster) convertFrom_Server(src *chev2.CheCluster) error {
 
 	if src.Spec.Components.CheServer.Deployment != nil {
 		if len(src.Spec.Components.CheServer.Deployment.Containers) != 0 {
+			dst.Spec.Server.CheServerEnv = src.Spec.Components.CheServer.Deployment.Containers[0].Env
 			cheServerImageAndTag := strings.Split(src.Spec.Components.CheServer.Deployment.Containers[0].Image, ":")
 			dst.Spec.Server.CheImage = strings.Join(cheServerImageAndTag[0:len(cheServerImageAndTag)-1], ":")
 			dst.Spec.Server.CheImageTag = cheServerImageAndTag[len(cheServerImageAndTag)-1]
@@ -116,12 +119,12 @@ func (dst *CheCluster) convertFrom_Server(src *chev2.CheCluster) error {
 
 			if src.Spec.Components.CheServer.Deployment.Containers[0].Resources != nil {
 				if src.Spec.Components.CheServer.Deployment.Containers[0].Resources.Requests != nil {
-					dst.Spec.Server.ServerMemoryRequest = src.Spec.Components.CheServer.Deployment.Containers[0].Resources.Requests.Memory.String()
-					dst.Spec.Server.ServerCpuRequest = src.Spec.Components.CheServer.Deployment.Containers[0].Resources.Requests.Cpu.String()
+					dst.Spec.Server.ServerMemoryRequest = resource2String(src.Spec.Components.CheServer.Deployment.Containers[0].Resources.Requests.Memory)
+					dst.Spec.Server.ServerCpuRequest = resource2String(src.Spec.Components.CheServer.Deployment.Containers[0].Resources.Requests.Cpu)
 				}
 				if src.Spec.Components.CheServer.Deployment.Containers[0].Resources.Limits != nil {
-					dst.Spec.Server.ServerMemoryLimit = src.Spec.Components.CheServer.Deployment.Containers[0].Resources.Limits.Memory.String()
-					dst.Spec.Server.ServerCpuLimit = src.Spec.Components.CheServer.Deployment.Containers[0].Resources.Limits.Cpu.String()
+					dst.Spec.Server.ServerMemoryLimit = resource2String(src.Spec.Components.CheServer.Deployment.Containers[0].Resources.Limits.Memory)
+					dst.Spec.Server.ServerCpuLimit = resource2String(src.Spec.Components.CheServer.Deployment.Containers[0].Resources.Limits.Cpu)
 				}
 			}
 		}
@@ -180,6 +183,7 @@ func (dst *CheCluster) convertFrom_Server(src *chev2.CheCluster) error {
 }
 
 func (dst *CheCluster) convertFrom_Server_PluginRegistry(src *chev2.CheCluster) error {
+	dst.Spec.Server.OpenVSXRegistryURL = src.Spec.Components.PluginRegistry.OpenVSXURL
 	dst.Spec.Server.ExternalPluginRegistry = src.Spec.Components.PluginRegistry.DisableInternalRegistry
 
 	if src.Spec.Components.PluginRegistry.DisableInternalRegistry {
@@ -190,17 +194,18 @@ func (dst *CheCluster) convertFrom_Server_PluginRegistry(src *chev2.CheCluster)
 
 	if src.Spec.Components.PluginRegistry.Deployment != nil {
 		if len(src.Spec.Components.PluginRegistry.Deployment.Containers) != 0 {
+			dst.Spec.Server.PluginRegistryEnv = src.Spec.Components.PluginRegistry.Deployment.Containers[0].Env
 			dst.Spec.Server.PluginRegistryImage = src.Spec.Components.PluginRegistry.Deployment.Containers[0].Image
 			dst.Spec.Server.PluginRegistryPullPolicy = src.Spec.Components.PluginRegistry.Deployment.Containers[0].ImagePullPolicy
 
 			if src.Spec.Components.PluginRegistry.Deployment.Containers[0].Resources != nil {
 				if src.Spec.Components.PluginRegistry.Deployment.Containers[0].Resources.Requests != nil {
-					dst.Spec.Server.PluginRegistryMemoryRequest = src.Spec.Components.PluginRegistry.Deployment.Containers[0].Resources.Requests.Memory.String()
-					dst.Spec.Server.PluginRegistryCpuRequest = src.Spec.Components.PluginRegistry.Deployment.Containers[0].Resources.Requests.Cpu.String()
+					dst.Spec.Server.PluginRegistryMemoryRequest = resource2String(src.Spec.Components.PluginRegistry.Deployment.Containers[0].Resources.Requests.Memory)
+					dst.Spec.Server.PluginRegistryCpuRequest = resource2String(src.Spec.Components.PluginRegistry.Deployment.Containers[0].Resources.Requests.Cpu)
 				}
 				if src.Spec.Components.PluginRegistry.Deployment.Containers[0].Resources.Limits != nil {
-					dst.Spec.Server.PluginRegistryMemoryLimit = src.Spec.Components.PluginRegistry.Deployment.Containers[0].Resources.Limits.Memory.String()
-					dst.Spec.Server.PluginRegistryCpuLimit = src.Spec.Components.PluginRegistry.Deployment.Containers[0].Resources.Limits.Cpu.String()
+					dst.Spec.Server.PluginRegistryMemoryLimit = resource2String(src.Spec.Components.PluginRegistry.Deployment.Containers[0].Resources.Limits.Memory)
+					dst.Spec.Server.PluginRegistryCpuLimit = resource2String(src.Spec.Components.PluginRegistry.Deployment.Containers[0].Resources.Limits.Cpu)
 				}
 			}
 		}
@@ -221,17 +226,18 @@ func (dst *CheCluster) convertFrom_Server_DevfileRegistry(src *chev2.CheCluster)
 
 	if src.Spec.Components.DevfileRegistry.Deployment != nil {
 		if len(src.Spec.Components.DevfileRegistry.Deployment.Containers) != 0 {
+			dst.Spec.Server.DevfileRegistryEnv = src.Spec.Components.DevfileRegistry.Deployment.Containers[0].Env
 			dst.Spec.Server.DevfileRegistryImage = src.Spec.Components.DevfileRegistry.Deployment.Containers[0].Image
 			dst.Spec.Server.DevfileRegistryPullPolicy = src.Spec.Components.DevfileRegistry.Deployment.Containers[0].ImagePullPolicy
 
 			if src.Spec.Components.DevfileRegistry.Deployment.Containers[0].Resources != nil {
 				if src.Spec.Components.DevfileRegistry.Deployment.Containers[0].Resources.Requests != nil {
-					dst.Spec.Server.DevfileRegistryMemoryRequest = src.Spec.Components.DevfileRegistry.Deployment.Containers[0].Resources.Requests.Memory.String()
-					dst.Spec.Server.DevfileRegistryCpuRequest = src.Spec.Components.DevfileRegistry.Deployment.Containers[0].Resources.Requests.Cpu.String()
+					dst.Spec.Server.DevfileRegistryMemoryRequest = resource2String(src.Spec.Components.DevfileRegistry.Deployment.Containers[0].Resources.Requests.Memory)
+					dst.Spec.Server.DevfileRegistryCpuRequest = resource2String(src.Spec.Components.DevfileRegistry.Deployment.Containers[0].Resources.Requests.Cpu)
 				}
 				if src.Spec.Components.DevfileRegistry.Deployment.Containers[0].Resources.Limits != nil {
-					dst.Spec.Server.DevfileRegistryMemoryLimit = src.Spec.Components.DevfileRegistry.Deployment.Containers[0].Resources.Limits.Memory.String()
-					dst.Spec.Server.DevfileRegistryCpuLimit = src.Spec.Components.DevfileRegistry.Deployment.Containers[0].Resources.Limits.Cpu.String()
+					dst.Spec.Server.DevfileRegistryMemoryLimit = resource2String(src.Spec.Components.DevfileRegistry.Deployment.Containers[0].Resources.Limits.Memory)
+					dst.Spec.Server.DevfileRegistryCpuLimit = resource2String(src.Spec.Components.DevfileRegistry.Deployment.Containers[0].Resources.Limits.Cpu)
 				}
 			}
 		}
@@ -243,16 +249,17 @@ func (dst *CheCluster) convertFrom_Server_DevfileRegistry(src *chev2.CheCluster)
 func (dst *CheCluster) convertFrom_Server_Dashboard(src *chev2.CheCluster) error {
 	if src.Spec.Components.Dashboard.Deployment != nil {
 		if len(src.Spec.Components.Dashboard.Deployment.Containers) != 0 {
+			dst.Spec.Server.DashboardEnv = src.Spec.Components.Dashboard.Deployment.Containers[0].Env
 			dst.Spec.Server.DashboardImage = src.Spec.Components.Dashboard.Deployment.Containers[0].Image
 			dst.Spec.Server.DashboardImagePullPolicy = string(src.Spec.Components.Dashboard.Deployment.Containers[0].ImagePullPolicy)
 			if src.Spec.Components.Dashboard.Deployment.Containers[0].Resources != nil {
 				if src.Spec.Components.Dashboard.Deployment.Containers[0].Resources.Requests != nil {
-					dst.Spec.Server.DashboardMemoryRequest = src.Spec.Components.Dashboard.Deployment.Containers[0].Resources.Requests.Memory.String()
-					dst.Spec.Server.DashboardCpuRequest = src.Spec.Components.Dashboard.Deployment.Containers[0].Resources.Requests.Cpu.String()
+					dst.Spec.Server.DashboardMemoryRequest = resource2String(src.Spec.Components.Dashboard.Deployment.Containers[0].Resources.Requests.Memory)
+					dst.Spec.Server.DashboardCpuRequest = resource2String(src.Spec.Components.Dashboard.Deployment.Containers[0].Resources.Requests.Cpu)
 				}
 				if src.Spec.Components.Dashboard.Deployment.Containers[0].Resources.Limits != nil {
-					dst.Spec.Server.DashboardMemoryLimit = src.Spec.Components.Dashboard.Deployment.Containers[0].Resources.Limits.Memory.String()
-					dst.Spec.Server.DashboardCpuLimit = src.Spec.Components.Dashboard.Deployment.Containers[0].Resources.Limits.Cpu.String()
+					dst.Spec.Server.DashboardMemoryLimit = resource2String(src.Spec.Components.Dashboard.Deployment.Containers[0].Resources.Limits.Memory)
+					dst.Spec.Server.DashboardCpuLimit = resource2String(src.Spec.Components.Dashboard.Deployment.Containers[0].Resources.Limits.Cpu)
 				}
 			}
 		}
@@ -294,8 +301,14 @@ func (dst *CheCluster) convertFrom_Auth(src *chev2.CheCluster) error {
 			switch c.Name {
 			case constants.GatewayAuthenticationContainerName:
 				dst.Spec.Auth.GatewayAuthenticationSidecarImage = c.Image
+				dst.Spec.Auth.GatewayOAuthProxyEnv = c.Env
 			case constants.GatewayAuthorizationContainerName:
 				dst.Spec.Auth.GatewayAuthorizationSidecarImage = c.Image
+				dst.Spec.Auth.GatewayKubeRbacProxyEnv = c.Env
+			case constants.GatewayConfigSideCarContainerName:
+				dst.Spec.Auth.GatewayConfigBumpEnv = c.Env
+			case constants.GatewayContainerName:
+				dst.Spec.Auth.GatewayEnv = c.Env
 			}
 		}
 	}
@@ -316,16 +329,17 @@ func (dst *CheCluster) convertFrom_Database(src *chev2.CheCluster) error {
 
 	if src.Spec.Components.Database.Deployment != nil {
 		if len(src.Spec.Components.Database.Deployment.Containers) != 0 {
+			dst.Spec.Database.PostgresEnv = src.Spec.Components.Database.Deployment.Containers[0].Env
 			dst.Spec.Database.PostgresImage = src.Spec.Components.Database.Deployment.Containers[0].Image
 			dst.Spec.Database.PostgresImagePullPolicy = src.Spec.Components.Database.Deployment.Containers[0].ImagePullPolicy
 			if src.Spec.Components.Database.Deployment.Containers[0].Resources != nil {
 				if src.Spec.Components.Database.Deployment.Containers[0].Resources.Requests != nil {
-					dst.Spec.Database.ChePostgresContainerResources.Requests.Memory = src.Spec.Components.Database.Deployment.Containers[0].Resources.Requests.Memory.String()
-					dst.Spec.Database.ChePostgresContainerResources.Requests.Cpu = src.Spec.Components.Database.Deployment.Containers[0].Resources.Requests.Cpu.String()
+					dst.Spec.Database.ChePostgresContainerResources.Requests.Memory = resource2String(src.Spec.Components.Database.Deployment.Containers[0].Resources.Requests.Memory)
+					dst.Spec.Database.ChePostgresContainerResources.Requests.Cpu = resource2String(src.Spec.Components.Database.Deployment.Containers[0].Resources.Requests.Cpu)
 				}
 				if src.Spec.Components.Database.Deployment.Containers[0].Resources.Limits != nil {
-					dst.Spec.Database.ChePostgresContainerResources.Limits.Memory = src.Spec.Components.Database.Deployment.Containers[0].Resources.Limits.Memory.String()
-					dst.Spec.Database.ChePostgresContainerResources.Limits.Cpu = src.Spec.Components.Database.Deployment.Containers[0].Resources.Limits.Cpu.String()
+					dst.Spec.Database.ChePostgresContainerResources.Limits.Memory = resource2String(src.Spec.Components.Database.Deployment.Containers[0].Resources.Limits.Memory)
+					dst.Spec.Database.ChePostgresContainerResources.Limits.Cpu = resource2String(src.Spec.Components.Database.Deployment.Containers[0].Resources.Limits.Cpu)
 				}
 			}
 		}
@@ -338,10 +352,13 @@ func (dst *CheCluster) convertFrom_DevWorkspace(src *chev2.CheCluster) error {
 	if src.Spec.Components.DevWorkspace.Deployment != nil {
 		if len(src.Spec.Components.DevWorkspace.Deployment.Containers) != 0 {
 			dst.Spec.DevWorkspace.ControllerImage = src.Spec.Components.DevWorkspace.Deployment.Containers[0].Image
+			dst.Spec.DevWorkspace.Env = src.Spec.Components.DevWorkspace.Deployment.Containers[0].Env
 		}
 	}
 
 	dst.Spec.DevWorkspace.RunningLimit = src.Spec.Components.DevWorkspace.RunningLimit
+	dst.Spec.DevWorkspace.SecondsOfInactivityBeforeIdling = src.Spec.DevEnvironments.SecondsOfInactivityBeforeIdling
+	dst.Spec.DevWorkspace.SecondsOfRunBeforeIdling = src.Spec.DevEnvironments.SecondsOfRunBeforeIdling
 	dst.Spec.DevWorkspace.Enable = true
 	return nil
 }
@@ -403,9 +420,14 @@ func (dst *CheCluster) convertFrom_Storage(src *chev2.CheCluster) error {
 	}
 
 	dst.Spec.Storage.PvcStrategy = src.Spec.DevEnvironments.Storage.PvcStrategy
-	if src.Spec.DevEnvironments.Storage.Pvc != nil {
-		dst.Spec.Storage.PvcClaimSize = src.Spec.DevEnvironments.Storage.Pvc.ClaimSize
-		dst.Spec.Storage.WorkspacePVCStorageClassName = src.Spec.DevEnvironments.Storage.Pvc.StorageClass
+	if src.Spec.DevEnvironments.Storage.PerUserStrategyPvcConfig != nil {
+		dst.Spec.Storage.PvcClaimSize = src.Spec.DevEnvironments.Storage.PerUserStrategyPvcConfig.ClaimSize
+		dst.Spec.Storage.WorkspacePVCStorageClassName = src.Spec.DevEnvironments.Storage.PerUserStrategyPvcConfig.StorageClass
+	}
+
+	if src.Spec.DevEnvironments.Storage.PerWorkspaceStrategyPvcConfig != nil {
+		dst.Spec.Storage.PerWorkspaceStrategyPvcClaimSize = src.Spec.DevEnvironments.Storage.PerWorkspaceStrategyPvcConfig.ClaimSize
+		dst.Spec.Storage.PerWorkspaceStrategyPVCStorageClassName = src.Spec.DevEnvironments.Storage.PerWorkspaceStrategyPvcConfig.StorageClass
 	}
 
 	return nil
@@ -423,3 +445,10 @@ func findTrustStoreConfigMap(namespace string) (string, error) {
 
 	return "", nil
 }
+
+func resource2String(resource resource.Quantity) string {
+	if resource.IsZero() {
+		return ""
+	}
+	return resource.String()
+}
