@@ -128,6 +128,8 @@ func (src *CheCluster) convertTo_DevEnvironments(dst *chev2.CheCluster) error {
 
 	dst.Spec.DevEnvironments.DefaultEditor = src.Spec.Server.WorkspaceDefaultEditor
 	dst.Spec.DevEnvironments.DefaultComponents = src.Spec.Server.WorkspaceDefaultComponents
+	dst.Spec.DevEnvironments.SecondsOfInactivityBeforeIdling = src.Spec.DevWorkspace.SecondsOfInactivityBeforeIdling
+	dst.Spec.DevEnvironments.SecondsOfRunBeforeIdling = src.Spec.DevWorkspace.SecondsOfRunBeforeIdling
 
 	if err := src.convertTo_Workspaces_Storage(dst); err != nil {
 		return err
@@ -137,7 +139,8 @@ func (src *CheCluster) convertTo_DevEnvironments(dst *chev2.CheCluster) error {
 }
 
 func (src *CheCluster) convertTo_Workspaces_Storage(dst *chev2.CheCluster) error {
-	dst.Spec.DevEnvironments.Storage.Pvc = toCheV2Pvc(src.Spec.Storage.PvcClaimSize, src.Spec.Storage.WorkspacePVCStorageClassName)
+	dst.Spec.DevEnvironments.Storage.PerUserStrategyPvcConfig = toCheV2Pvc(src.Spec.Storage.PvcClaimSize, src.Spec.Storage.WorkspacePVCStorageClassName)
+	dst.Spec.DevEnvironments.Storage.PerWorkspaceStrategyPvcConfig = toCheV2Pvc(src.Spec.Storage.PerWorkspaceStrategyPvcClaimSize, src.Spec.Storage.PerWorkspaceStrategyPVCStorageClassName)
 	dst.Spec.DevEnvironments.Storage.PvcStrategy = src.Spec.Storage.PvcStrategy
 	return nil
 }
@@ -197,62 +200,20 @@ func (src *CheCluster) convertTo_Networking_Auth(dst *chev2.CheCluster) error {
 func (src *CheCluster) convertTo_Networking_Auth_Gateway(dst *chev2.CheCluster) error {
 	dst.Spec.Networking.Auth.Gateway.ConfigLabels = utils.CloneMap(src.Spec.Server.SingleHostGatewayConfigMapLabels)
 
-	if src.Spec.Server.SingleHostGatewayImage != "" {
-		if dst.Spec.Networking.Auth.Gateway.Deployment == nil {
-			dst.Spec.Networking.Auth.Gateway.Deployment = &chev2.Deployment{}
+	containers2add := append([]*chev2.Container{},
+		toCheV2ContainerWithImageAndEnv(constants.GatewayContainerName, src.Spec.Server.SingleHostGatewayImage, src.Spec.Auth.GatewayEnv),
+		toCheV2ContainerWithImageAndEnv(constants.GatewayConfigSideCarContainerName, src.Spec.Server.SingleHostGatewayConfigSidecarImage, src.Spec.Auth.GatewayConfigBumpEnv),
+		toCheV2ContainerWithImageAndEnv(constants.GatewayAuthenticationContainerName, src.Spec.Auth.GatewayAuthenticationSidecarImage, src.Spec.Auth.GatewayOAuthProxyEnv),
+		toCheV2ContainerWithImageAndEnv(constants.GatewayAuthorizationContainerName, src.Spec.Auth.GatewayAuthorizationSidecarImage, src.Spec.Auth.GatewayKubeRbacProxyEnv))
+
+	for _, container := range containers2add {
+		if container != nil {
+			if dst.Spec.Networking.Auth.Gateway.Deployment == nil {
+				dst.Spec.Networking.Auth.Gateway.Deployment = &chev2.Deployment{}
+			}
+			dst.Spec.Networking.Auth.Gateway.Deployment.Containers = append(dst.Spec.Networking.Auth.Gateway.Deployment.Containers, *container)
 		}
-
-		dst.Spec.Networking.Auth.Gateway.Deployment.Containers = append(
-			dst.Spec.Networking.Auth.Gateway.Deployment.Containers,
-			chev2.Container{
-				Name:  constants.GatewayContainerName,
-				Image: src.Spec.Server.SingleHostGatewayImage,
-			},
-		)
 	}
-
-	if src.Spec.Server.SingleHostGatewayConfigSidecarImage != "" {
-		if dst.Spec.Networking.Auth.Gateway.Deployment == nil {
-			dst.Spec.Networking.Auth.Gateway.Deployment = &chev2.Deployment{}
-		}
-
-		dst.Spec.Networking.Auth.Gateway.Deployment.Containers = append(
-			dst.Spec.Networking.Auth.Gateway.Deployment.Containers,
-			chev2.Container{
-				Name:  constants.GatewayConfigSideCarContainerName,
-				Image: src.Spec.Server.SingleHostGatewayConfigSidecarImage,
-			},
-		)
-	}
-
-	if src.Spec.Auth.GatewayAuthenticationSidecarImage != "" {
-		if dst.Spec.Networking.Auth.Gateway.Deployment == nil {
-			dst.Spec.Networking.Auth.Gateway.Deployment = &chev2.Deployment{}
-		}
-
-		dst.Spec.Networking.Auth.Gateway.Deployment.Containers = append(
-			dst.Spec.Networking.Auth.Gateway.Deployment.Containers,
-			chev2.Container{
-				Name:  constants.GatewayAuthenticationContainerName,
-				Image: src.Spec.Auth.GatewayAuthenticationSidecarImage,
-			},
-		)
-	}
-
-	if src.Spec.Auth.GatewayAuthorizationSidecarImage != "" {
-		if dst.Spec.Networking.Auth.Gateway.Deployment == nil {
-			dst.Spec.Networking.Auth.Gateway.Deployment = &chev2.Deployment{}
-		}
-
-		dst.Spec.Networking.Auth.Gateway.Deployment.Containers = append(
-			dst.Spec.Networking.Auth.Gateway.Deployment.Containers,
-			chev2.Container{
-				Name:  constants.GatewayAuthorizationContainerName,
-				Image: src.Spec.Auth.GatewayAuthorizationSidecarImage,
-			},
-		)
-	}
-
 	return nil
 }
 
@@ -293,18 +254,15 @@ func (src *CheCluster) convertTo_Components(dst *chev2.CheCluster) error {
 }
 
 func (src *CheCluster) convertTo_Components_DevWorkspace(dst *chev2.CheCluster) error {
-	if src.Spec.DevWorkspace.ControllerImage != "" {
-		dst.Spec.Components.DevWorkspace.Deployment = &chev2.Deployment{
-			Containers: []chev2.Container{
-				{
-					Name:  constants.DevWorkspaceController,
-					Image: src.Spec.DevWorkspace.ControllerImage,
-				},
-			},
-		}
+	container := toCheV2ContainerWithImageAndEnv(
+		constants.DevWorkspaceController,
+		src.Spec.DevWorkspace.ControllerImage,
+		src.Spec.DevWorkspace.Env)
+	if container != nil {
+		dst.Spec.Components.DevWorkspace.Deployment = &chev2.Deployment{Containers: []chev2.Container{*container}}
 	}
-	dst.Spec.Components.DevWorkspace.RunningLimit = src.Spec.DevWorkspace.RunningLimit
 
+	dst.Spec.Components.DevWorkspace.RunningLimit = src.Spec.DevWorkspace.RunningLimit
 	return nil
 }
 
@@ -380,6 +338,7 @@ func (src *CheCluster) convertTo_Components_CheServer(dst *chev2.CheCluster) err
 		src.Spec.Server.ServerCpuLimit,
 		fsGroup,
 		runAsUser,
+		src.Spec.Server.CheServerEnv,
 	)
 
 	if src.Spec.Server.ServerTrustStoreConfigMapName != "" {
@@ -392,6 +351,7 @@ func (src *CheCluster) convertTo_Components_CheServer(dst *chev2.CheCluster) err
 }
 
 func (src *CheCluster) convertTo_Components_PluginRegistry(dst *chev2.CheCluster) error {
+	dst.Spec.Components.PluginRegistry.OpenVSXURL = src.Spec.Server.OpenVSXRegistryURL
 	dst.Spec.Components.PluginRegistry.DisableInternalRegistry = src.Spec.Server.ExternalPluginRegistry
 
 	if dst.Spec.Components.PluginRegistry.DisableInternalRegistry {
@@ -412,6 +372,7 @@ func (src *CheCluster) convertTo_Components_PluginRegistry(dst *chev2.CheCluster
 		src.Spec.Server.PluginRegistryCpuLimit,
 		nil,
 		nil,
+		src.Spec.Server.PluginRegistryEnv,
 	)
 
 	return nil
@@ -437,6 +398,7 @@ func (src *CheCluster) convertTo_Components_DevfileRegistry(dst *chev2.CheCluste
 		src.Spec.Server.DevfileRegistryCpuLimit,
 		nil,
 		nil,
+		src.Spec.Server.DevfileRegistryEnv,
 	)
 
 	return nil
@@ -466,6 +428,7 @@ func (src *CheCluster) convertTo_Components_Database(dst *chev2.CheCluster) erro
 		src.Spec.Database.ChePostgresContainerResources.Limits.Cpu,
 		nil,
 		nil,
+		src.Spec.Database.PostgresEnv,
 	)
 
 	dst.Spec.Components.Database.ExternalDb = src.Spec.Database.ExternalDb
@@ -493,6 +456,7 @@ func (src *CheCluster) convertTo_Components_Dashboard(dst *chev2.CheCluster) err
 		src.Spec.Server.DashboardCpuLimit,
 		fsGroup,
 		runAsUser,
+		src.Spec.Server.DashboardEnv,
 	)
 
 	if src.Spec.Dashboard.Warning != "" {
@@ -620,6 +584,31 @@ func renameTrustStoreConfigMapToDefault(trustStoreConfigMapName string, namespac
 	return nil
 }
 
+func toCheV2ContainerWithImageAndEnv(
+	name string,
+	image string,
+	env []corev1.EnvVar) *chev2.Container {
+
+	var container *chev2.Container
+	if image != "" {
+		container = &chev2.Container{
+			Name:  name,
+			Image: image,
+		}
+	}
+
+	if len(env) != 0 {
+		if container == nil {
+			container = &chev2.Container{
+				Name: name,
+			}
+		}
+		container.Env = env
+	}
+
+	return container
+}
+
 func toCheV2Deployment(
 	name string,
 	image string,
@@ -629,7 +618,8 @@ func toCheV2Deployment(
 	cpuRequest string,
 	cpuLimit string,
 	fsGroup *int64,
-	runAsUser *int64) *chev2.Deployment {
+	runAsUser *int64,
+	env []corev1.EnvVar) *chev2.Deployment {
 
 	var deployment *chev2.Deployment
 	var container *chev2.Container
@@ -643,11 +633,16 @@ func toCheV2Deployment(
 	}
 
 	if memoryRequest != "" || cpuRequest != "" {
-		resources = &chev2.ResourceRequirements{
-			Requests: &chev2.ResourceList{
-				Memory: resource.MustParse(memoryRequest),
-				Cpu:    resource.MustParse(cpuRequest),
-			},
+		if resources == nil {
+			resources = &chev2.ResourceRequirements{}
+		}
+		resources.Requests = &chev2.ResourceList{}
+
+		if memoryRequest != "" {
+			resources.Requests.Memory = resource.MustParse(memoryRequest)
+		}
+		if cpuRequest != "" {
+			resources.Requests.Cpu = resource.MustParse(cpuRequest)
 		}
 	}
 
@@ -655,10 +650,13 @@ func toCheV2Deployment(
 		if resources == nil {
 			resources = &chev2.ResourceRequirements{}
 		}
+		resources.Limits = &chev2.ResourceList{}
 
-		resources.Limits = &chev2.ResourceList{
-			Memory: resource.MustParse(memoryLimit),
-			Cpu:    resource.MustParse(cpuLimit),
+		if memoryLimit != "" {
+			resources.Limits.Memory = resource.MustParse(memoryLimit)
+		}
+		if cpuLimit != "" {
+			resources.Limits.Cpu = resource.MustParse(cpuLimit)
 		}
 	}
 
@@ -669,6 +667,13 @@ func toCheV2Deployment(
 		container.Resources = resources
 	}
 
+	if len(env) != 0 {
+		if container == nil {
+			container = &chev2.Container{}
+		}
+		container.Env = env
+	}
+
 	if runAsUser != nil || fsGroup != nil {
 		if deployment == nil {
 			deployment = &chev2.Deployment{}
