@@ -251,7 +251,7 @@ type CheClusterSpecServer struct {
 	// Default value is `Always` for `nightly`, `next` or `latest` images, and `IfNotPresent` in other cases.
 	// +optional
 	PluginRegistryPullPolicy corev1.PullPolicy `json:"pluginRegistryPullPolicy,omitempty"`
-	// Overrides the memory limit used in the plugin registry deployment. Defaults to 256Mi.
+	// Overrides the memory limit used in the plugin registry deployment. Defaults to 1536Mi.
 	// +optional
 	PluginRegistryMemoryLimit string `json:"pluginRegistryMemoryLimit,omitempty"`
 	// Overrides the memory request used in the plugin registry deployment. Defaults to 16Mi.
@@ -366,6 +366,21 @@ type CheClusterSpecServer struct {
 	// These default components are meant to be used when a Devfile does not contain any components.
 	// +optional
 	WorkspaceDefaultComponents []devfile.Component `json:"workspaceDefaultComponents,omitempty"`
+	// List of environment variables to set in the Che server container.
+	// +optional
+	CheServerEnv []corev1.EnvVar `json:"cheServerEnv,omitempty"`
+	// List of environment variables to set in the plugin registry container.
+	// +optional
+	DevfileRegistryEnv []corev1.EnvVar `json:"devfileRegistryEnv,omitempty"`
+	// List of environment variables to set in the devfile registry container.
+	// +optional
+	PluginRegistryEnv []corev1.EnvVar `json:"pluginRegistryEnv,omitempty"`
+	// List of environment variables to set in the dashboard container.
+	// +optional
+	DashboardEnv []corev1.EnvVar `json:"dashboardEnv,omitempty"`
+	// Open VSX registry URL. If omitted an embedded instance will be used.
+	// +optional
+	OpenVSXRegistryURL string `json:"openVSXRegistryURL,omitempty"`
 }
 
 // +k8s:openapi-gen=true
@@ -420,6 +435,9 @@ type CheClusterSpecDB struct {
 	// To update pvc storageclass that provisions it must support resize when Eclipse Che has been already deployed.
 	// +optional
 	PvcClaimSize string `json:"pvcClaimSize,omitempty"`
+	// List of environment variables to set in the PostgreSQL container.
+	// +optional
+	PostgresEnv []corev1.EnvVar `json:"postgresEnv,omitempty"`
 }
 
 // +k8s:openapi-gen=true
@@ -560,6 +578,18 @@ type CheClusterSpecAuth struct {
 	// Deprecated. The value of this flag is ignored.
 	// Debug internal identity provider.
 	Debug bool `json:"debug,omitempty"`
+	// List of environment variables to set in the Gateway container.
+	// +optional
+	GatewayEnv []corev1.EnvVar `json:"gatewayEnv,omitempty"`
+	// List of environment variables to set in the Configbump container.
+	// +optional
+	GatewayConfigBumpEnv []corev1.EnvVar `json:"gatewayConfigBumpEnv,omitempty"`
+	// List of environment variables to set in the OAuth proxy container.
+	// +optional
+	GatewayOAuthProxyEnv []corev1.EnvVar `json:"gatewayOAuthProxyEnv,omitempty"`
+	// List of environment variables to set in the Kube rbac proxy container.
+	// +optional
+	GatewayKubeRbacProxyEnv []corev1.EnvVar `json:"gatewayKubeRbacProxyEnv,omitempty"`
 }
 
 // Ingress custom settings, can be extended in the future
@@ -646,6 +676,12 @@ type CheClusterSpecStorage struct {
 	// Storage class for the Persistent Volume Claims dedicated to the Che workspaces. When omitted or left blank, a default storage class is used.
 	// +optional
 	WorkspacePVCStorageClassName string `json:"workspacePVCStorageClassName,omitempty"`
+	// Size of the persistent volume claim for workspaces.
+	// +optional
+	PerWorkspaceStrategyPvcClaimSize string `json:"perWorkspaceStrategyPvcClaimSize,omitempty"`
+	// Storage class for the Persistent Volume Claims dedicated to the Che workspaces. When omitted or left blank, a default storage class is used.
+	// +optional
+	PerWorkspaceStrategyPVCStorageClassName string `json:"perWorkspaceStrategyPVCStorageClassName,omitempty"`
 }
 
 // +k8s:openapi-gen=true
@@ -724,6 +760,19 @@ type CheClusterSpecDevWorkspace struct {
 	// Maximum number of the running workspaces per user.
 	// +optional
 	RunningLimit string `json:"runningLimit,omitempty"`
+	// Idle timeout for workspaces in seconds.
+	// This timeout is the duration after which a workspace will be idled if there is no activity.
+	// To disable workspace idling due to inactivity, set this value to -1.
+	// +kubebuilder:default:=1800
+	SecondsOfInactivityBeforeIdling *int32 `json:"secondsOfInactivityBeforeIdling,omitempty"`
+	// Run timeout for workspaces in seconds.
+	// This timeout is the maximum duration a workspace runs.
+	// To disable workspace run timeout, set this value to -1.
+	// +kubebuilder:default:=-1
+	SecondsOfRunBeforeIdling *int32 `json:"secondsOfRunBeforeIdling,omitempty"`
+	// List of environment variables to set in the DevWorkspace container.
+	// +optional
+	Env []corev1.EnvVar `json:"env,omitempty"`
 }
 
 // +k8s:openapi-gen=true
@@ -866,6 +915,7 @@ type CheClusterStatus struct {
 // +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
 // +kubebuilder:object:root=true
 // +kubebuilder:subresource:status
+// +kubebuilder:deprecatedversion:warning="org.eclipse.che/v1 CheCluster is deprecated and will be removed in future releases"
 // +k8s:openapi-gen=true
 // +operator-sdk:csv:customresourcedefinitions:displayName="Eclipse Che instance Specification"
 // +operator-sdk:csv:customresourcedefinitions:order=1
