@@ -37,7 +37,7 @@ type CheClusterSpec struct {
 	// +optional
 	// +operator-sdk:csv:customresourcedefinitions:type=spec,order=1
 	// +operator-sdk:csv:customresourcedefinitions:type=spec,displayName="Development environments"
-	// +kubebuilder:default:={storage: {pvcStrategy: common}, defaultNamespace: {template: <username>-devspaces}}
+	// +kubebuilder:default:={storage: {pvcStrategy: per-user}, defaultNamespace: {template: <username>-devspaces}, secondsOfInactivityBeforeIdling:1800, secondsOfRunBeforeIdling:-1}
 	DevEnvironments CheClusterDevEnvironments `json:"devEnvironments"`
 	// Che components configuration.
 	// +optional
@@ -63,7 +63,7 @@ type CheClusterSpec struct {
 type CheClusterDevEnvironments struct {
 	// Workspaces persistent storage.
 	// +optional
-	// +kubebuilder:default:={pvcStrategy: common}
+	// +kubebuilder:default:={pvcStrategy: per-user}
 	Storage WorkspaceStorage `json:"storage,omitempty"`
 	// Default plug-ins applied to DevWorkspaces.
 	// +optional
@@ -90,6 +90,16 @@ type CheClusterDevEnvironments struct {
 	// These default components are meant to be used when a Devfile, that does not contain any components.
 	// +optional
 	DefaultComponents []devfile.Component `json:"defaultComponents,omitempty"`
+	// Idle timeout for workspaces in seconds.
+	// This timeout is the duration after which a workspace will be idled if there is no activity.
+	// To disable workspace idling due to inactivity, set this value to -1.
+	// +kubebuilder:default:=1800
+	SecondsOfInactivityBeforeIdling *int32 `json:"secondsOfInactivityBeforeIdling,omitempty"`
+	// Run timeout for workspaces in seconds.
+	// This timeout is the maximum duration a workspace runs.
+	// To disable workspace run timeout, set this value to -1.
+	// +kubebuilder:default:=-1
+	SecondsOfRunBeforeIdling *int32 `json:"secondsOfRunBeforeIdling,omitempty"`
 }
 
 // Che components configuration.
@@ -232,6 +242,9 @@ type PluginRegistry struct {
 	// External plugin registries.
 	// +optional
 	ExternalPluginRegistries []ExternalPluginRegistry `json:"externalPluginRegistries,omitempty"`
+	// Open VSX registry URL. If omitted an embedded instance will be used.
+	// +optional
+	OpenVSXURL string `json:"openVSXURL,omitempty"`
 }
 
 // Configuration settings related to the devfile registry used by the Che installation.
@@ -340,7 +353,7 @@ type DashboardHeaderMessage struct {
 	Show bool `json:"show,omitempty"`
 	// Warning message displayed on the user dashboard.
 	// +optional
-	Text string `json:"warning,text"`
+	Text string `json:"text,omitempty"`
 }
 
 type TrustedCerts struct {
@@ -353,15 +366,19 @@ type TrustedCerts struct {
 
 // Configuration settings related to the workspaces persistent storage.
 type WorkspaceStorage struct {
-	// PVC settings.
+	// PVC settings when using the `per-user` PVC strategy.
 	// +optional
-	Pvc *PVC `json:"pvc,omitempty"`
+	PerUserStrategyPvcConfig *PVC `json:"perUserStrategyPvcConfig,omitempty"`
+	// PVC settings when using the `per-workspace` PVC strategy.
+	// +optional
+	PerWorkspaceStrategyPvcConfig *PVC `json:"perWorkspaceStrategyPvcConfig,omitempty"`
 	// Persistent volume claim strategy for the Che server.
-	// Only the `common` strategy (all workspaces PVCs in one volume) is supported .
+	// The supported strategies are: `per-user` (all workspaces PVCs in one volume)
+	// and 'per-workspace' (each workspace is given its own individual PVC).
 	// For details, see https://github.com/eclipse/che/issues/21185.
 	// +optional
-	// +kubebuilder:default:="common"
-	// +kubebuilder:validation:Enum=common;per-workspace
+	// +kubebuilder:default:="per-user"
+	// +kubebuilder:validation:Enum=common;per-user;per-workspace
 	PvcStrategy string `json:"pvcStrategy,omitempty"`
 }
 
@@ -499,6 +516,9 @@ type Container struct {
 	// Compute resources required by this container.
 	// +optional
 	Resources *ResourceRequirements `json:"resources,omitempty"`
+	// List of environment variables to set in the container.
+	// +optional
+	Env []corev1.EnvVar `json:"env,omitempty"`
 }
 
 // Describes the compute resource requirements.
