@@ -18,22 +18,17 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/eclipse-che/che-operator/pkg/util"
-
 	"github.com/stretchr/testify/assert"
 
-	"github.com/eclipse-che/che-operator/pkg/deploy/gateway"
-
 	dw "github.com/devfile/api/v2/pkg/apis/workspaces/v1alpha2"
 	dwo "github.com/devfile/devworkspace-operator/apis/controller/v1alpha1"
 	"github.com/devfile/devworkspace-operator/controllers/controller/devworkspacerouting/solvers"
 	"github.com/devfile/devworkspace-operator/pkg/constants"
 	"github.com/devfile/devworkspace-operator/pkg/infrastructure"
-	org "github.com/eclipse-che/che-operator/api"
-	v1 "github.com/eclipse-che/che-operator/api/v1"
-	"github.com/eclipse-che/che-operator/api/v2alpha1"
+	chev2 "github.com/eclipse-che/che-operator/api/v2"
 	controller "github.com/eclipse-che/che-operator/controllers/devworkspace"
 	"github.com/eclipse-che/che-operator/controllers/devworkspace/defaults"
+	"github.com/eclipse-che/che-operator/pkg/deploy/gateway"
 	routev1 "github.com/openshift/api/route/v1"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
@@ -59,15 +54,15 @@ func createTestScheme() *runtime.Scheme {
 	utilruntime.Must(dw.AddToScheme(scheme))
 	utilruntime.Must(dwo.AddToScheme(scheme))
 	utilruntime.Must(routev1.AddToScheme(scheme))
-	utilruntime.Must(v1.AddToScheme(scheme))
+	utilruntime.Must(chev2.AddToScheme(scheme))
 
 	return scheme
 }
 
-func getSpecObjectsForManager(t *testing.T, mgr *v2alpha1.CheCluster, routing *dwo.DevWorkspaceRouting, additionalInitialObjects ...runtime.Object) (client.Client, solvers.RoutingSolver, solvers.RoutingObjects) {
+func getSpecObjectsForManager(t *testing.T, mgr *chev2.CheCluster, routing *dwo.DevWorkspaceRouting, additionalInitialObjects ...runtime.Object) (client.Client, solvers.RoutingSolver, solvers.RoutingObjects) {
 	scheme := createTestScheme()
 
-	allObjs := []runtime.Object{asV1(mgr)}
+	allObjs := []runtime.Object{mgr}
 	for i := range additionalInitialObjects {
 		allObjs = append(allObjs, additionalInitialObjects[i])
 	}
@@ -103,20 +98,16 @@ func getSpecObjectsForManager(t *testing.T, mgr *v2alpha1.CheCluster, routing *d
 }
 
 func getSpecObjects(t *testing.T, routing *dwo.DevWorkspaceRouting) (client.Client, solvers.RoutingSolver, solvers.RoutingObjects) {
-	return getSpecObjectsForManager(t, &v2alpha1.CheCluster{
+	return getSpecObjectsForManager(t, &chev2.CheCluster{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:       "che",
 			Namespace:  "ns",
 			Finalizers: []string{controller.FinalizerName},
 		},
-		Spec: v2alpha1.CheClusterSpec{
-			Gateway: v2alpha1.CheGatewaySpec{
-				Host: "over.the.rainbow",
-			},
-			Workspaces: v2alpha1.Workspaces{
-				DomainEndpoints: v2alpha1.DomainEndpoints{
-					BaseDomain: "down.on.earth",
-				},
+		Spec: chev2.CheClusterSpec{
+			Networking: chev2.CheClusterSpecNetworking{
+				Domain:   "down.on.earth",
+				Hostname: "over.the.rainbow",
 			},
 		},
 	}, routing)
@@ -207,8 +198,7 @@ func relocatableDevWorkspaceRouting() *dwo.DevWorkspaceRouting {
 }
 
 func TestCreateRelocatedObjectsK8S(t *testing.T) {
-	util.IsOpenShift = false
-	util.IsOpenShift4 = false
+	infrastructure.InitializeForTesting(infrastructure.Kubernetes)
 	cl, _, objs := getSpecObjects(t, relocatableDevWorkspaceRouting())
 
 	t.Run("noIngresses", func(t *testing.T) {
@@ -312,12 +302,14 @@ func TestCreateRelocatedObjectsK8S(t *testing.T) {
 
 		workspaceMainConfig := gateway.TraefikConfig{}
 		assert.NoError(t, yaml.Unmarshal([]byte(traefikMainWorkspaceConfig), &workspaceMainConfig))
-		assert.Len(t, workspaceMainConfig.HTTP.Middlewares, 2)
+		assert.Len(t, workspaceMainConfig.HTTP.Middlewares, 4)
 
 		wsid = "wsid"
 		mwares = []string{
 			wsid + gateway.AuthMiddlewareSuffix,
-			wsid + gateway.StripPrefixMiddlewareSuffix}
+			wsid + gateway.StripPrefixMiddlewareSuffix,
+			wsid + gateway.HeadersMiddlewareSuffix,
+			wsid + gateway.ErrorsMiddlewareSuffix}
 		for _, mware := range mwares {
 			assert.Contains(t, workspaceMainConfig.HTTP.Middlewares, mware)
 
@@ -330,6 +322,14 @@ func TestCreateRelocatedObjectsK8S(t *testing.T) {
 			assert.Truef(t, found, "traefik config route doesn't set middleware '%s'", mware)
 		}
 
+		t.Run("testServerTransportIsEmpty", func(t *testing.T) {
+			assert.Empty(t, workspaceMainConfig.HTTP.ServersTransports)
+
+			assert.Len(t, workspaceMainConfig.HTTP.Services, 1)
+			assert.Contains(t, workspaceMainConfig.HTTP.Services, wsid)
+			assert.Empty(t, workspaceMainConfig.HTTP.Services[wsid].LoadBalancer.ServersTransport)
+		})
+
 		t.Run("testHealthzEndpointInMainWorkspaceRoute", func(t *testing.T) {
 			healthzName := "wsid-9999-healthz"
 			assert.Contains(t, workspaceMainConfig.HTTP.Routers, healthzName)
@@ -353,8 +353,7 @@ func TestCreateRelocatedObjectsK8S(t *testing.T) {
 }
 
 func TestCreateRelocatedObjectsOpenshift(t *testing.T) {
-	util.IsOpenShift = true
-	util.IsOpenShift4 = true
+	infrastructure.InitializeForTesting(infrastructure.OpenShiftv4)
 
 	cl, _, objs := getSpecObjects(t, relocatableDevWorkspaceRouting())
 
@@ -403,13 +402,15 @@ func TestCreateRelocatedObjectsOpenshift(t *testing.T) {
 
 		workspaceMainConfig := gateway.TraefikConfig{}
 		assert.NoError(t, yaml.Unmarshal([]byte(traefikMainWorkspaceConfig), &workspaceMainConfig))
-		assert.Len(t, workspaceMainConfig.HTTP.Middlewares, 3)
+		assert.Len(t, workspaceMainConfig.HTTP.Middlewares, 5)
 
 		wsid = "wsid"
 		mwares := []string{
 			wsid + gateway.AuthMiddlewareSuffix,
 			wsid + gateway.StripPrefixMiddlewareSuffix,
-			wsid + gateway.HeaderRewriteMiddlewareSuffix}
+			wsid + gateway.HeaderRewriteMiddlewareSuffix,
+			wsid + gateway.HeadersMiddlewareSuffix,
+			wsid + gateway.ErrorsMiddlewareSuffix}
 		for _, mware := range mwares {
 			assert.Contains(t, workspaceMainConfig.HTTP.Middlewares, mware)
 
@@ -422,6 +423,17 @@ func TestCreateRelocatedObjectsOpenshift(t *testing.T) {
 			assert.Truef(t, found, "traefik config route doesn't set middleware '%s'", mware)
 		}
 
+		t.Run("testServerTransportInMainWorkspaceRoute", func(t *testing.T) {
+			serverTransportName := wsid
+
+			assert.Len(t, workspaceMainConfig.HTTP.ServersTransports, 1)
+			assert.Contains(t, workspaceMainConfig.HTTP.ServersTransports, serverTransportName)
+
+			assert.Len(t, workspaceMainConfig.HTTP.Services, 1)
+			assert.Contains(t, workspaceMainConfig.HTTP.Services, wsid)
+			assert.Equal(t, workspaceMainConfig.HTTP.Services[wsid].LoadBalancer.ServersTransport, serverTransportName)
+		})
+
 		t.Run("testHealthzEndpointInMainWorkspaceRoute", func(t *testing.T) {
 			healthzName := "wsid-9999-healthz"
 			assert.Contains(t, workspaceMainConfig.HTTP.Routers, healthzName)
@@ -520,8 +532,7 @@ func TestUniqueMainEndpoint(t *testing.T) {
 
 func TestCreateSubDomainObjects(t *testing.T) {
 	testCommon := func(infra infrastructure.Type) solvers.RoutingObjects {
-		util.IsOpenShift = infra == infrastructure.OpenShiftv4
-		util.IsOpenShift4 = infra == infrastructure.OpenShiftv4
+		infrastructure.InitializeForTesting(infra)
 
 		cl, _, objs := getSpecObjects(t, subdomainDevWorkspaceRouting())
 
@@ -592,8 +603,7 @@ func TestCreateSubDomainObjects(t *testing.T) {
 
 func TestReportRelocatableExposedEndpoints(t *testing.T) {
 	// kubernetes
-	util.IsOpenShift = false
-	util.IsOpenShift4 = false
+	infrastructure.InitializeForTesting(infrastructure.Kubernetes)
 
 	routing := relocatableDevWorkspaceRouting()
 	_, solver, objs := getSpecObjects(t, routing)
@@ -645,9 +655,118 @@ func TestReportRelocatableExposedEndpoints(t *testing.T) {
 	}
 }
 
+func TestExposeEndpoints(t *testing.T) {
+	infrastructure.InitializeForTesting(infrastructure.Kubernetes)
+
+	routing := &dwo.DevWorkspaceRouting{
+		ObjectMeta: metav1.ObjectMeta{
+			Name:      "routing",
+			Namespace: "ws",
+		},
+		Spec: dwo.DevWorkspaceRoutingSpec{
+			DevWorkspaceId: "wsid",
+			RoutingClass:   "che",
+			Endpoints: map[string]dwo.EndpointList{
+				"server-internal": {
+					{
+						Name:       "server-int",
+						TargetPort: 8081,
+						Exposure:   dwo.InternalEndpointExposure,
+						Protocol:   "http",
+						Attributes: map[string]apiext.JSON{
+							"urlRewriteSupported": apiext.JSON{Raw: []byte("\"true\"")},
+							"cookiesAuthEnabled":  apiext.JSON{Raw: []byte("\"true\"")},
+						},
+					},
+				},
+				"server-internal-no-rewrite": {
+					{
+						Name:       "server-int-nr",
+						TargetPort: 8084,
+						Exposure:   dwo.InternalEndpointExposure,
+						Protocol:   "http",
+					},
+				},
+				"server-none": {
+					{
+						Name:       "server-int",
+						TargetPort: 8080,
+						Exposure:   dwo.NoneEndpointExposure,
+						Protocol:   "http",
+						Attributes: map[string]apiext.JSON{
+							"urlRewriteSupported": apiext.JSON{Raw: []byte("\"true\"")},
+							"cookiesAuthEnabled":  apiext.JSON{Raw: []byte("\"true\"")},
+						},
+					},
+				},
+				"server-none-no-rewrite": {
+					{
+						Name:       "server-none-nr",
+						TargetPort: 8083,
+						Exposure:   dwo.NoneEndpointExposure,
+						Protocol:   "http",
+					},
+				},
+				"server-public": {
+					{
+						Name:       "server-pub",
+						TargetPort: 8082,
+						Exposure:   dwo.PublicEndpointExposure,
+						Protocol:   "http",
+						Attributes: map[string]apiext.JSON{
+							"urlRewriteSupported": apiext.JSON{Raw: []byte("\"true\"")},
+							"cookiesAuthEnabled":  apiext.JSON{Raw: []byte("\"true\"")},
+						},
+					},
+				},
+				"server-public-no-rewrite": {
+					{
+						Name:       "server-pub-nr",
+						TargetPort: 8085,
+						Exposure:   dwo.PublicEndpointExposure,
+						Protocol:   "http",
+					},
+				},
+			},
+		},
+	}
+
+	_, solver, objs := getSpecObjects(t, routing)
+
+	assert.Equal(t, 1, len(objs.Ingresses))
+
+	exposed, ready, err := solver.GetExposedEndpoints(routing.Spec.Endpoints, objs)
+	assert.Nil(t, err)
+	assert.True(t, ready)
+	assert.Equal(t, 4, len(exposed))
+
+	si, ok := exposed["server-internal"]
+	assert.True(t, ok)
+	assert.Equal(t, 1, len(si))
+	assert.Equal(t, "server-int", si[0].Name)
+	assert.Equal(t, "http://wsid-service.ws.svc:8081", si[0].Url)
+
+	sinr, ok := exposed["server-internal-no-rewrite"]
+	assert.True(t, ok)
+	assert.Equal(t, 1, len(sinr))
+	assert.Equal(t, "server-int-nr", sinr[0].Name)
+	assert.Equal(t, "http://wsid-service.ws.svc:8084", sinr[0].Url)
+
+	sp, ok := exposed["server-public"]
+	assert.True(t, ok)
+	assert.Equal(t, 1, len(sp))
+	assert.Equal(t, "server-pub", sp[0].Name)
+	assert.Equal(t, "https://over.the.rainbow/wsid/server-public/8082/", sp[0].Url)
+
+	spnr, ok := exposed["server-public-no-rewrite"]
+	assert.True(t, ok)
+	assert.Equal(t, 1, len(spnr))
+	assert.Equal(t, "server-pub-nr", spnr[0].Name)
+	assert.Equal(t, "http://wsid-1.down.on.earth/", spnr[0].Url)
+}
+
 func TestReportSubdomainExposedEndpoints(t *testing.T) {
-	util.IsOpenShift = false
-	util.IsOpenShift4 = false
+	infrastructure.InitializeForTesting(infrastructure.Kubernetes)
 	routing := subdomainDevWorkspaceRouting()
 	_, solver, objs := getSpecObjects(t, routing)
 
@@ -699,8 +818,7 @@ func TestReportSubdomainExposedEndpoints(t *testing.T) {
 }
 
 func TestFinalize(t *testing.T) {
-	util.IsOpenShift = false
-	util.IsOpenShift4 = false
+	infrastructure.InitializeForTesting(infrastructure.Kubernetes)
 	routing := relocatableDevWorkspaceRouting()
 	cl, slv, _ := getSpecObjects(t, routing)
 
@@ -721,8 +839,7 @@ func TestFinalize(t *testing.T) {
 }
 
 func TestEndpointsAlwaysOnSecureProtocolsWhenExposedThroughGateway(t *testing.T) {
-	util.IsOpenShift = false
-	util.IsOpenShift4 = false
+	infrastructure.InitializeForTesting(infrastructure.Kubernetes)
 	routing := relocatableDevWorkspaceRouting()
 	_, slv, objs := getSpecObjects(t, routing)
 
@@ -745,26 +862,19 @@ func TestEndpointsAlwaysOnSecureProtocolsWhenExposedThroughGateway(t *testing.T)
 }
 
 func TestUsesIngressAnnotationsForWorkspaceEndpointIngresses(t *testing.T) {
-	util.IsOpenShift = false
-	util.IsOpenShift4 = false
+	infrastructure.InitializeForTesting(infrastructure.Kubernetes)
 
-	mgr := &v2alpha1.CheCluster{
+	mgr := &chev2.CheCluster{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:       "che",
 			Namespace:  "ns",
 			Finalizers: []string{controller.FinalizerName},
 		},
-		Spec: v2alpha1.CheClusterSpec{
-			Gateway: v2alpha1.CheGatewaySpec{
-				Host: "over.the.rainbow",
-			},
-			Workspaces: v2alpha1.Workspaces{
-				DomainEndpoints: v2alpha1.DomainEndpoints{
-					BaseDomain: "down.on.earth",
-				},
-			},
-			K8s: v2alpha1.CheClusterSpecK8s{
-				IngressAnnotations: map[string]string{
+		Spec: chev2.CheClusterSpec{
+			Networking: chev2.CheClusterSpecNetworking{
+				Hostname: "over.the.rainbow",
+				Domain:   "down.on.earth",
+				Annotations: map[string]string{
 					"a": "b",
 				},
 			},
@@ -789,24 +899,19 @@ func TestUsesIngressAnnotationsForWorkspaceEndpointIngresses(t *testing.T) {
 }
 
 func TestUsesCustomCertificateForWorkspaceEndpointIngresses(t *testing.T) {
-	util.IsOpenShift = false
-	util.IsOpenShift4 = false
+	infrastructure.InitializeForTesting(infrastructure.Kubernetes)
 
-	mgr := &v2alpha1.CheCluster{
+	mgr := &chev2.CheCluster{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:       "che",
 			Namespace:  "ns",
 			Finalizers: []string{controller.FinalizerName},
 		},
-		Spec: v2alpha1.CheClusterSpec{
-			Gateway: v2alpha1.CheGatewaySpec{
-				Host: "beyond.comprehension",
-			},
-			Workspaces: v2alpha1.Workspaces{
-				DomainEndpoints: v2alpha1.DomainEndpoints{
-					BaseDomain:    "almost.trivial",
-					TlsSecretName: "tlsSecret",
-				},
+		Spec: chev2.CheClusterSpec{
+			Networking: chev2.CheClusterSpecNetworking{
+				TlsSecretName: "tlsSecret",
+				Hostname:      "beyond.comprehension",
+				Domain:        "almost.trivial",
 			},
 		},
 	}
@@ -870,24 +975,19 @@ func TestUsesCustomCertificateForWorkspaceEndpointIngresses(t *testing.T) {
 }
 
 func TestUsesCustomCertificateForWorkspaceEndpointRoutes(t *testing.T) {
-	util.IsOpenShift = true
-	util.IsOpenShift4 = true
+	infrastructure.InitializeForTesting(infrastructure.OpenShiftv4)
 
-	mgr := &v2alpha1.CheCluster{
+	mgr := &chev2.CheCluster{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:       "che",
 			Namespace:  "ns",
 			Finalizers: []string{controller.FinalizerName},
 		},
-		Spec: v2alpha1.CheClusterSpec{
-			Gateway: v2alpha1.CheGatewaySpec{
-				Host: "beyond.comprehension",
-			},
-			Workspaces: v2alpha1.Workspaces{
-				DomainEndpoints: v2alpha1.DomainEndpoints{
-					BaseDomain:    "almost.trivial",
-					TlsSecretName: "tlsSecret",
-				},
+		Spec: chev2.CheClusterSpec{
+			Networking: chev2.CheClusterSpecNetworking{
+				Hostname:      "beyond.comprehension",
+				TlsSecretName: "tlsSecret",
+				Domain:        "almost.trivial",
 			},
 		},
 	}
@@ -933,9 +1033,3 @@ func TestUsesCustomCertificateForWorkspaceEndpointRoutes(t *testing.T) {
 		t.Errorf("Unexpected TLS on the route: %s", route.Spec.TLS)
 	}
 }
-
-func asV1(v2Obj *v2alpha1.CheCluster) *v1.CheCluster {
-	v1 := org.AsV1(v2Obj)
-	v1.Status.CheURL = "https://" + v1.Spec.Server.CheHost
-	return v1
-}
