@@ -15,6 +15,7 @@ package usernamespace
 import (
 	"context"
 	"encoding/json"
+	"strconv"
 
 	"github.com/eclipse-che/che-operator/pkg/common/chetypes"
 	"github.com/eclipse-che/che-operator/pkg/common/constants"
@@ -238,6 +239,11 @@ func (r *CheUserNamespaceReconciler) Reconcile(ctx context.Context, req ctrl.Req
 		return ctrl.Result{}, err
 	}
 
+	if err = r.reconcileIdleSettings(ctx, req.Name, checluster, deployContext); err != nil {
+		logrus.Errorf("Failed to reconcile idle settings into namespace '%s': %v", req.Name, err)
+		return ctrl.Result{}, err
+	}
+
 	if err = r.reconcileNodeSelectorAndTolerations(ctx, req.Name, checluster, deployContext); err != nil {
 		logrus.Errorf("Failed to reconcile the workspace pod node selector and tolerations in namespace '%s': %v", req.Name, err)
 		return ctrl.Result{}, err
@@ -448,6 +454,49 @@ func (r *CheUserNamespaceReconciler) reconcileProxySettings(ctx context.Context,
 	return err
 }
 
+func (r *CheUserNamespaceReconciler) reconcileIdleSettings(ctx context.Context, targetNs string, checluster *chev2.CheCluster, deployContext *chetypes.DeployContext) error {
+
+	if checluster.Spec.DevEnvironments.SecondsOfInactivityBeforeIdling == nil && checluster.Spec.DevEnvironments.SecondsOfRunBeforeIdling == nil {
+		return nil
+	}
+	configMapName := prefixedName("idle-settings")
+	cfg := &corev1.ConfigMap{}
+
+	requiredLabels := defaults.AddStandardLabelsForComponent(checluster, userSettingsComponentLabelValue, map[string]string{
+		dwconstants.DevWorkspaceMountLabel:          "true",
+		dwconstants.DevWorkspaceWatchConfigMapLabel: "true",
+	})
+	requiredAnnos := map[string]string{
+		dwconstants.DevWorkspaceMountAsAnnotation: "env",
+	}
+
+	data := map[string]string{}
+
+	if checluster.Spec.DevEnvironments.SecondsOfInactivityBeforeIdling != nil {
+		data["SECONDS_OF_DW_INACTIVITY_BEFORE_IDLING"] = strconv.FormatInt(int64(*checluster.Spec.DevEnvironments.SecondsOfInactivityBeforeIdling), 10)
+	}
+
+	if checluster.Spec.DevEnvironments.SecondsOfRunBeforeIdling != nil {
+		data["SECONDS_OF_DW_RUN_BEFORE_IDLING"] = strconv.FormatInt(int64(*checluster.Spec.DevEnvironments.SecondsOfRunBeforeIdling), 10)
+	}
+
+	cfg = &corev1.ConfigMap{
+		TypeMeta: metav1.TypeMeta{
+			Kind:       "ConfigMap",
+			APIVersion: "v1",
+		},
+		ObjectMeta: metav1.ObjectMeta{
+			Name:        configMapName,
+			Namespace:   targetNs,
+			Labels:      requiredLabels,
+			Annotations: requiredAnnos,
+		},
+		Data: data,
+	}
+	_, err := deploy.DoSync(deployContext, cfg, deploy.ConfigMapDiffOpts)
+	return err
+}
+
 func (r *CheUserNamespaceReconciler) reconcileGitTlsCertificate(ctx context.Context, targetNs string, checluster *chev2.CheCluster, deployContext *chetypes.DeployContext) error {
 	if err := deleteLegacyObject("git-tls-creds", &corev1.ConfigMap{}, targetNs, checluster, deployContext); err != nil {
 		return err
@@ -496,14 +545,7 @@ func (r *CheUserNamespaceReconciler) reconcileGitTlsCertificate(ctx context.Cont
 }
 
 func (r *CheUserNamespaceReconciler) reconcileNodeSelectorAndTolerations(ctx context.Context, targetNs string, checluster *chev2.CheCluster, deployContext *chetypes.DeployContext) error {
-	var ns client.Object
-
-	if infrastructure.IsOpenShift() {
-		ns = &projectv1.Project{}
-	} else {
-		ns = &corev1.Namespace{}
-	}
-
+	ns := &corev1.Namespace{}
 	if err := r.client.Get(ctx, client.ObjectKey{Name: targetNs}, ns); err != nil {
 		return err
 	}
