@@ -76,6 +76,8 @@ func setupCheCluster(t *testing.T, ctx context.Context, cl client.Client, scheme
 				TrustedCerts: &chev2.TrustedCerts{
 					GitTrustedCertsConfigMapName: "che-git-self-signed-cert",
 				},
+				SecondsOfInactivityBeforeIdling: pointer.Int32Ptr(1800),
+				SecondsOfRunBeforeIdling:        pointer.Int32Ptr(-1),
 			},
 			Networking: chev2.CheClusterSpecNetworking{
 				Domain: "root-domain",
@@ -245,42 +247,56 @@ func TestRequiresLabelsToMatchOneOfMultipleCheCluster(t *testing.T) {
 }
 
 func TestMatchingCheClusterCanBeSelectedUsingLabels(t *testing.T) {
-	test := func(t *testing.T, infraType devworkspaceinfra.Type, namespace metav1.Object) {
+	test := func(t *testing.T, infraType devworkspaceinfra.Type, namespace string, objs ...runtime.Object) {
 		ctx := context.TODO()
-		scheme, cl, r := setup(infraType, namespace.(runtime.Object))
+		scheme, cl, r := setup(infraType, objs...)
 		setupCheCluster(t, ctx, cl, scheme, "che1", "che")
 		setupCheCluster(t, ctx, cl, scheme, "che2", "che")
 
-		res, err := r.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: namespace.GetName()}})
+		res, err := r.Reconcile(context.TODO(), reconcile.Request{NamespacedName: types.NamespacedName{Name: namespace}})
 		assert.NoError(t, err, "Reconciliation shouldn't have failed")
 
 		assert.False(t, res.Requeue, "The reconciliation request should have succeeded but is requesting a requeue.")
 	}
 
 	t.Run("k8s", func(t *testing.T) {
-		test(t, devworkspaceinfra.Kubernetes, &corev1.Namespace{
-			ObjectMeta: metav1.ObjectMeta{
-				Name: "ns",
-				Labels: map[string]string{
-					workspaceNamespaceOwnerUidLabel: "uid",
-					cheNameLabel:                    "che",
-					cheNamespaceLabel:               "che1",
+		test(t, devworkspaceinfra.Kubernetes,
+			"ns",
+			&corev1.Namespace{
+				ObjectMeta: metav1.ObjectMeta{
+					Name: "ns",
+					Labels: map[string]string{
+						workspaceNamespaceOwnerUidLabel: "uid",
+						cheNameLabel:                    "che",
+						cheNamespaceLabel:               "che1",
+					},
 				},
-			},
-		})
+			})
 	})
 
 	t.Run("openshift", func(t *testing.T) {
-		test(t, devworkspaceinfra.OpenShiftv4, &projectv1.Project{
-			ObjectMeta: metav1.ObjectMeta{
-				Name: "prj",
-				Labels: map[string]string{
-					workspaceNamespaceOwnerUidLabel: "uid",
-					cheNameLabel:                    "che",
-					cheNamespaceLabel:               "che1",
+		test(t, devworkspaceinfra.OpenShiftv4,
+			"ns",
+			&corev1.Namespace{
+				ObjectMeta: metav1.ObjectMeta{
+					Name: "ns",
+					Labels: map[string]string{
+						workspaceNamespaceOwnerUidLabel: "uid",
+						cheNameLabel:                    "che",
+						cheNamespaceLabel:               "che1",
+					},
 				},
 			},
-		})
+			&projectv1.Project{
+				ObjectMeta: metav1.ObjectMeta{
+					Name: "prj",
+					Labels: map[string]string{
+						workspaceNamespaceOwnerUidLabel: "uid",
+						cheNameLabel:                    "che",
+						cheNamespaceLabel:               "che1",
+					},
+				},
+			})
 	})
 }
 
@@ -325,6 +341,20 @@ func TestCreatesDataInNamespace(t *testing.T) {
 
 		assert.Equal(t, ".svc", proxySettings.Data["NO_PROXY"], "Unexpected proxy settings")
 
+		idleSettings := corev1.ConfigMap{}
+		assert.NoError(t, cl.Get(ctx, client.ObjectKey{Name: "che-idle-settings", Namespace: namespace.GetName()}, &idleSettings))
+
+		assert.Equal(t, "env", idleSettings.GetAnnotations()[dwconstants.DevWorkspaceMountAsAnnotation],
+			"idle settings should be annotated as mount as 'env'")
+
+		assert.Equal(t, "true", idleSettings.GetLabels()[dwconstants.DevWorkspaceMountLabel],
+			"idle settings should be labeled as mounted")
+
+		assert.Equal(t, 2, len(idleSettings.Data), "Expecting 2 elements in the idle settings")
+
+		assert.Equal(t, "1800", idleSettings.Data["SECONDS_OF_DW_INACTIVITY_BEFORE_IDLING"], "Unexpected idle settings")
+		assert.Equal(t, "-1", idleSettings.Data["SECONDS_OF_DW_RUN_BEFORE_IDLING"], "Unexpected idle settings")
+
 		cert := corev1.Secret{}
 		assert.NoError(t, cl.Get(ctx, client.ObjectKey{Name: "che-server-cert", Namespace: namespace.GetName()}, &cert))
 
@@ -371,24 +401,33 @@ func TestCreatesDataInNamespace(t *testing.T) {
 	})
 
 	t.Run("openshift", func(t *testing.T) {
-		test(t, devworkspaceinfra.OpenShiftv4, &projectv1.Project{
-			ObjectMeta: metav1.ObjectMeta{
-				Name: "prj",
-				Labels: map[string]string{
-					workspaceNamespaceOwnerUidLabel: "uid",
+		test(t, devworkspaceinfra.OpenShiftv4,
+			&corev1.Namespace{
+				ObjectMeta: metav1.ObjectMeta{
+					Name: "prj",
+					Labels: map[string]string{
+						workspaceNamespaceOwnerUidLabel: "uid",
+					},
 				},
 			},
-		}, &configv1.Proxy{
-			ObjectMeta: metav1.ObjectMeta{
-				Name: "cluster",
-			},
-			Spec: configv1.ProxySpec{
-				NoProxy: ".svc",
-			},
-			Status: configv1.ProxyStatus{
-				NoProxy: ".svc",
-			},
-		})
+			&projectv1.Project{
+				ObjectMeta: metav1.ObjectMeta{
+					Name: "prj",
+					Labels: map[string]string{
+						workspaceNamespaceOwnerUidLabel: "uid",
+					},
+				},
+			}, &configv1.Proxy{
+				ObjectMeta: metav1.ObjectMeta{
+					Name: "cluster",
+				},
+				Spec: configv1.ProxySpec{
+					NoProxy: ".svc",
+				},
+				Status: configv1.ProxyStatus{
+					NoProxy: ".svc",
+				},
+			})
 	})
 }
 
