@@ -17,6 +17,8 @@ import (
 	"os"
 	"strconv"
 
+	"github.com/eclipse-che/che-operator/pkg/common/chetypes"
+	"github.com/eclipse-che/che-operator/pkg/common/constants"
 	"github.com/eclipse-che/che-operator/pkg/deploy"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
@@ -25,12 +27,12 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/client"
 )
 
-func createDwNamespace(deployContext *deploy.DeployContext) (bool, error) {
+func createDwNamespace(deployContext *chetypes.DeployContext) (bool, error) {
 	namespace := &corev1.Namespace{
 		ObjectMeta: metav1.ObjectMeta{
 			Name: DevWorkspaceNamespace,
 			Annotations: map[string]string{
-				deploy.CheEclipseOrgNamespace: deployContext.CheCluster.Namespace,
+				constants.CheEclipseOrgNamespace: deployContext.CheCluster.Namespace,
 			},
 		},
 		Spec: corev1.NamespaceSpec{},
@@ -48,15 +50,15 @@ func isNoOptDWO() (bool, error) {
 	return strconv.ParseBool(value)
 }
 
-func isDevWorkspaceOperatorHasOwner(ctx *deploy.DeployContext) (bool, error) {
+func isDevWorkspaceOperatorHasOwner(ctx *chetypes.DeployContext) (bool, error) {
 	deployments := &appsv1.DeploymentList{}
 	if err := ctx.ClusterAPI.NonCachingClient.List(
 		context.TODO(),
 		deployments,
 		&client.ListOptions{
 			LabelSelector: labels.SelectorFromSet(map[string]string{
-				deploy.KubernetesPartOfLabelKey: deploy.DevWorkspaceOperator,
-				deploy.KubernetesNameLabelKey:   deploy.DevWorkspaceController,
+				constants.KubernetesPartOfLabelKey: constants.DevWorkspaceOperator,
+				constants.KubernetesNameLabelKey:   constants.DevWorkspaceController,
 			}),
 		}); err != nil {
 		return false, err
