@@ -390,7 +390,7 @@ func TestEnvVars(t *testing.T) {
 
 	// unset RELATED_IMAGE environment variables, set them back
 	// after tests complete
-	matches := utils.GetEnvByRegExp("^RELATED_IMAGE_.*")
+	matches := utils.GetEnvsByRegExp("^RELATED_IMAGE_.*")
 	for _, match := range matches {
 		if originalValue, exists := os.LookupEnv(match.Name); exists {
 			os.Unsetenv(match.Name)
