@@ -132,14 +132,6 @@ func (s *CheServerReconciler) getCheConfigMapData(ctx *chetypes.DeployContext) (
 		}
 	}
 
-	pvcStrategy := utils.GetValue(ctx.CheCluster.Spec.DevEnvironments.Storage.PvcStrategy, constants.DefaultPvcStrategy)
-	workspacePvcStorageClassName := ""
-	pvcClaimSize := constants.DefaultPvcClaimSize
-	if ctx.CheCluster.Spec.DevEnvironments.Storage.Pvc != nil {
-		pvcClaimSize = ctx.CheCluster.Spec.DevEnvironments.Storage.Pvc.ClaimSize
-		workspacePvcStorageClassName = ctx.CheCluster.Spec.DevEnvironments.Storage.Pvc.StorageClass
-	}
-
 	chePostgresHostName := utils.GetValue(ctx.CheCluster.Spec.Components.Database.PostgresHostName, constants.DefaultPostgresHostName)
 	chePostgresPort := utils.GetValue(ctx.CheCluster.Spec.Components.Database.PostgresPort, constants.DefaultPostgresPort)
 	chePostgresDb := utils.GetValue(ctx.CheCluster.Spec.Components.Database.PostgresDb, constants.DefaultPostgresDb)
@@ -204,9 +196,6 @@ func (s *CheServerReconciler) getCheConfigMapData(ctx *chetypes.DeployContext) (
 		CheInfraKubernetesServiceAccountName:   cheWorkspaceServiceAccount,
 		CheInfraKubernetesUserClusterRoles:     cheUserClusterRoleNames,
 		DefaultTargetNamespace:                 workspaceNamespaceDefault,
-		PvcStrategy:                            pvcStrategy,
-		PvcClaimSize:                           pvcClaimSize,
-		WorkspacePvcStorageClassName:           workspacePvcStorageClassName,
 		TlsSupport:                             "true",
 		K8STrustCerts:                          "true",
 		CheLogLevel:                            cheLogLevel,
