@@ -131,7 +131,7 @@ func TestDeployment(t *testing.T) {
 	}
 }
 
-func TestMountBitBucketOAuthEnvVar(t *testing.T) {
+func TestMountBitBucketServerOAuthEnvVar(t *testing.T) {
 	type testCase struct {
 		name                    string
 		initObjects             []runtime.Object
@@ -152,7 +152,7 @@ func TestMountBitBucketOAuthEnvVar(t *testing.T) {
 						APIVersion: "v1",
 					},
 					ObjectMeta: metav1.ObjectMeta{
-						Name:      "github-oauth-config",
+						Name:      "bitbucket-oauth-config",
 						Namespace: "eclipse-che",
 						Labels: map[string]string{
 							"app.kubernetes.io/part-of":   "che.eclipse.org",
@@ -173,15 +173,15 @@ func TestMountBitBucketOAuthEnvVar(t *testing.T) {
 			expectedPrivateKeyPath:  "/che-conf/oauth/bitbucket/private.key",
 			expectedOAuthEndpoint:   "endpoint_1",
 			expectedVolume: corev1.Volume{
-				Name: "github-oauth-config",
+				Name: "bitbucket-oauth-config",
 				VolumeSource: corev1.VolumeSource{
 					Secret: &corev1.SecretVolumeSource{
-						SecretName: "github-oauth-config",
+						SecretName: "bitbucket-oauth-config",
 					},
 				},
 			},
 			expectedVolumeMount: corev1.VolumeMount{
-				Name:      "github-oauth-config",
+				Name:      "bitbucket-oauth-config",
 				MountPath: "/che-conf/oauth/bitbucket",
 			},
 		},
@@ -197,20 +197,102 @@ func TestMountBitBucketOAuthEnvVar(t *testing.T) {
 
 			container := &deployment.Spec.Template.Spec.Containers[0]
 
-			value := utils.GetEnv(container.Env, "CHE_OAUTH1_BITBUCKET_CONSUMERKEYPATH")
+			value := utils.GetEnvByName("CHE_OAUTH1_BITBUCKET_CONSUMERKEYPATH", container.Env)
 			assert.Equal(t, testCase.expectedConsumerKeyPath, value)
 
-			value = utils.GetEnv(container.Env, "CHE_OAUTH1_BITBUCKET_PRIVATEKEYPATH")
+			value = utils.GetEnvByName("CHE_OAUTH1_BITBUCKET_PRIVATEKEYPATH", container.Env)
 			assert.Equal(t, testCase.expectedPrivateKeyPath, value)
 
-			value = utils.GetEnv(container.Env, "CHE_OAUTH1_BITBUCKET_ENDPOINT")
+			value = utils.GetEnvByName("CHE_OAUTH1_BITBUCKET_ENDPOINT", container.Env)
 			assert.Equal(t, testCase.expectedOAuthEndpoint, value)
 
-			volume := test.FindVolume(deployment.Spec.Template.Spec.Volumes, "github-oauth-config")
+			volume := test.FindVolume(deployment.Spec.Template.Spec.Volumes, "bitbucket-oauth-config")
 			assert.NotNil(t, volume)
 			assert.Equal(t, testCase.expectedVolume, volume)
 
-			volumeMount := test.FindVolumeMount(container.VolumeMounts, "github-oauth-config")
+			volumeMount := test.FindVolumeMount(container.VolumeMounts, "bitbucket-oauth-config")
+			assert.NotNil(t, volumeMount)
+			assert.Equal(t, testCase.expectedVolumeMount, volumeMount)
+		})
+	}
+}
+
+func TestMountBitbucketOAuthEnvVar(t *testing.T) {
+	type testCase struct {
+		name                  string
+		initObjects           []runtime.Object
+		expectedIdKeyPath     string
+		expectedSecretKeyPath string
+		expectedOAuthEndpoint string
+		expectedVolume        corev1.Volume
+		expectedVolumeMount   corev1.VolumeMount
+	}
+
+	testCases := []testCase{
+		{
+			name: "Test",
+			initObjects: []runtime.Object{
+				&corev1.Secret{
+					TypeMeta: metav1.TypeMeta{
+						Kind:       "Secret",
+						APIVersion: "v1",
+					},
+					ObjectMeta: metav1.ObjectMeta{
+						Name:      "bitbucket-oauth-config",
+						Namespace: "eclipse-che",
+						Labels: map[string]string{
+							"app.kubernetes.io/part-of":   "che.eclipse.org",
+							"app.kubernetes.io/component": "oauth-scm-configuration",
+						},
+						Annotations: map[string]string{
+							"che.eclipse.org/oauth-scm-server":    "bitbucket",
+							"che.eclipse.org/scm-server-endpoint": "endpoint_1",
+						},
+					},
+					Data: map[string][]byte{
+						"id":     []byte("some_id"),
+						"secret": []byte("some_secret"),
+					},
+				},
+			},
+			expectedIdKeyPath:     "/che-conf/oauth/bitbucket/id",
+			expectedSecretKeyPath: "/che-conf/oauth/bitbucket/secret",
+			expectedVolume: corev1.Volume{
+				Name: "bitbucket-oauth-config",
+				VolumeSource: corev1.VolumeSource{
+					Secret: &corev1.SecretVolumeSource{
+						SecretName: "bitbucket-oauth-config",
+					},
+				},
+			},
+			expectedVolumeMount: corev1.VolumeMount{
+				Name:      "bitbucket-oauth-config",
+				MountPath: "/che-conf/oauth/bitbucket",
+			},
+		},
+	}
+
+	for _, testCase := range testCases {
+		t.Run(testCase.name, func(t *testing.T) {
+			ctx := test.GetDeployContext(nil, testCase.initObjects)
+
+			server := NewCheServerReconciler()
+			deployment, err := server.getDeploymentSpec(ctx)
+			assert.Nil(t, err, "Unexpected error %v", err)
+
+			container := &deployment.Spec.Template.Spec.Containers[0]
+
+			value := utils.GetEnvByName("CHE_OAUTH2_BITBUCKET_CLIENTID__FILEPATH", container.Env)
+			assert.Equal(t, testCase.expectedIdKeyPath, value)
+
+			value = utils.GetEnvByName("CHE_OAUTH2_BITBUCKET_CLIENTSECRET__FILEPATH", container.Env)
+			assert.Equal(t, testCase.expectedSecretKeyPath, value)
+
+			volume := test.FindVolume(deployment.Spec.Template.Spec.Volumes, "bitbucket-oauth-config")
+			assert.NotNil(t, volume)
+			assert.Equal(t, testCase.expectedVolume, volume)
+
+			volumeMount := test.FindVolumeMount(container.VolumeMounts, "bitbucket-oauth-config")
 			assert.NotNil(t, volumeMount)
 			assert.Equal(t, testCase.expectedVolumeMount, volumeMount)
 		})
@@ -283,13 +365,13 @@ func TestMountGitHubOAuthEnvVar(t *testing.T) {
 
 			container := &deployment.Spec.Template.Spec.Containers[0]
 
-			value := utils.GetEnv(container.Env, "CHE_OAUTH2_GITHUB_CLIENTID__FILEPATH")
+			value := utils.GetEnvByName("CHE_OAUTH2_GITHUB_CLIENTID__FILEPATH", container.Env)
 			assert.Equal(t, testCase.expectedIdKeyPath, value)
 
-			value = utils.GetEnv(container.Env, "CHE_OAUTH2_GITHUB_CLIENTSECRET__FILEPATH")
+			value = utils.GetEnvByName("CHE_OAUTH2_GITHUB_CLIENTSECRET__FILEPATH", container.Env)
 			assert.Equal(t, testCase.expectedSecretKeyPath, value)
 
-			value = utils.GetEnv(container.Env, "CHE_INTEGRATION_GITHUB_OAUTH__ENDPOINT")
+			value = utils.GetEnvByName("CHE_INTEGRATION_GITHUB_OAUTH__ENDPOINT", container.Env)
 			assert.Equal(t, testCase.expectedOAuthEndpoint, value)
 
 			volume := test.FindVolume(deployment.Spec.Template.Spec.Volumes, "github-oauth-config")
@@ -369,13 +451,13 @@ func TestMountGitLabOAuthEnvVar(t *testing.T) {
 
 			container := &deployment.Spec.Template.Spec.Containers[0]
 
-			value := utils.GetEnv(container.Env, "CHE_OAUTH2_GITLAB_CLIENTID__FILEPATH")
+			value := utils.GetEnvByName("CHE_OAUTH2_GITLAB_CLIENTID__FILEPATH", container.Env)
 			assert.Equal(t, testCase.expectedIdKeyPath, value)
 
-			value = utils.GetEnv(container.Env, "CHE_OAUTH2_GITLAB_CLIENTSECRET__FILEPATH")
+			value = utils.GetEnvByName("CHE_OAUTH2_GITLAB_CLIENTSECRET__FILEPATH", container.Env)
 			assert.Equal(t, testCase.expectedSecretKeyPath, value)
 
-			value = utils.GetEnv(container.Env, "CHE_INTEGRATION_GITLAB_OAUTH__ENDPOINT")
+			value = utils.GetEnvByName("CHE_INTEGRATION_GITLAB_OAUTH__ENDPOINT", container.Env)
 			assert.Equal(t, testCase.expectedOAuthEndpoint, value)
 
 			volume := test.FindVolume(deployment.Spec.Template.Spec.Volumes, "gitlab-oauth-config")
